@@ -2,8 +2,8 @@
 """
 import math
 
-from .db import CorpsEval
-from db_hj3415 import mongo, setting
+from .db import CorpsEval, MONGO_ADDR
+from db_hj3415 import mongo2
 from util_hj3415 import utils
 from krx_hj3415 import krx
 import pandas as pd
@@ -24,22 +24,22 @@ logger.setLevel(logging.WARNING)
 EXPECT_EARN = 0.04
 
 
-def red(code: str) -> dict:
+def red(client, code: str) -> dict:
     if utils.is_6digit(code):
         corps_eval = CorpsEval(code)
-        c101 = mongo.C101(code)
-        c103 = mongo.C103(code)
+        c101 = mongo2.C101(client, code)
+        c103 = mongo2.C103(client, code, 'c103재무상태표q')
     else:
         raise ValueError(f'Invalid code: {code}')
 
-    d1, 지배주주당기순이익 = corps_eval.calc당기순이익(nan_to_zero=True)
-    d2, 유동자산 = corps_eval.calc유동자산(nan_to_zero=True)
-    d3, 유동부채 = corps_eval.calc유동부채(nan_to_zero=True)
-    d4, 부채평가 = corps_eval.calc비유동부채(nan_to_zero=True)
+    d1, 지배주주당기순이익 = corps_eval.calc당기순이익()
+    d2, 유동자산 = corps_eval.calc유동자산()
+    d3, 유동부채 = corps_eval.calc유동부채()
+    d4, 부채평가 = corps_eval.calc비유동부채()
 
-    c103.chg_page('c103재무상태표q')
-    d5, 투자자산 = c103.latest_value('투자자산', nan_to_zero=True)
-    d6, 투자부동산 = c103.latest_value('투자부동산', nan_to_zero=True)
+    c103.page = 'c103재무상태표q'
+    d5, 투자자산 = c103.latest_value('투자자산')
+    d6, 투자부동산 = c103.latest_value('투자부동산')
 
     # 사업가치 계산 - 지배주주지분 당기순이익 / 기대수익률
     사업가치 = round(지배주주당기순이익 / EXPECT_EARN, 2)
@@ -72,11 +72,11 @@ def red(code: str) -> dict:
     }
 
 
-def mil(code: str) -> dict:
+def mil(client, code: str) -> dict:
     if utils.is_6digit(code):
         corps_eval = CorpsEval(code)
-        c103 = mongo.C103(code)
-        c104 = mongo.C104(code)
+        c103 = mongo2.C103(client, code, 'c103현금흐름표q')
+        c104 = mongo2.C104(client, code, 'c104q')
     else:
         raise ValueError(f'Invalid code: {code}')
 
@@ -84,13 +84,11 @@ def mil(code: str) -> dict:
     logger.info(f'{code} market cap: {marketcap}')
     fcf_dict = corps_eval.findFCF()
     pfcf_dict = corps_eval.findPFCF()
-    d1, 지배주주당기순이익 = corps_eval.calc당기순이익(nan_to_zero=True)
+    d1, 지배주주당기순이익 = corps_eval.calc당기순이익()
 
-    c103.chg_page('c103현금흐름표q')
-    d2, 재무활동현금흐름 = c103.sum_recent_4q(title='재무활동으로인한현금흐름', nan_to_zero=True)
-    d3, 영업활동현금흐름 = c103.sum_recent_4q(title='영업활동으로인한현금흐름', nan_to_zero=True)
+    d2, 재무활동현금흐름 = c103.sum_recent_4q(title='재무활동으로인한현금흐름')
+    d3, 영업활동현금흐름 = c103.sum_recent_4q(title='영업활동으로인한현금흐름')
 
-    c104.chg_page('c104q')
     d4, roic = c104.sum_recent_4q('ROIC')
     d5, roe = c104.latest_value('ROE')
     pcr_dict = c104.find('PCR')
@@ -112,7 +110,7 @@ def mil(code: str) -> dict:
     }
 
 
-def blue(code: str) -> dict:
+def blue(client, code: str) -> dict:
     """
     <유동비율>
     100미만이면 주의하나 현금흐름창출력이 좋으면 괜찮을수 있다.
@@ -136,7 +134,7 @@ def blue(code: str) -> dict:
 
     if utils.is_6digit(code):
         corps_eval = CorpsEval(code)
-        c104 = mongo.C104(code)
+        c104 = mongo2.C104(client, code, 'c104y')
     else:
         raise ValueError(f'Invalid code: {code}')
 
@@ -147,13 +145,12 @@ def blue(code: str) -> dict:
 
     ###############################################################
 
-    c104.chg_page('c104y')
     dict이자보상배율 = c104.find('이자보상배율')
     dict순운전자본회전율 = c104.find('순운전자본회전율')
     dict재고자산회전율 = c104.find('재고자산회전율')
     dict순부채비율 = c104.find('순부채비율')
 
-    c104.chg_page('c104q')
+    c104.page = 'c104q'
     d2, 이자보상배율 = c104.latest_value('이자보상배율')
     d3, 순운전자본회전율 = c104.latest_value('순운전자본회전율')
     d4, 재고자산회전율 = c104.latest_value('재고자산회전율')
@@ -176,7 +173,7 @@ def blue(code: str) -> dict:
     }
 
 
-def growth(code: str) -> dict:
+def growth(client, code: str) -> dict:
     """
     <매출액>
     매출액은 어떤경우에도 성장하는 기업이 좋다.매출이 20%씩 늘어나는 종목은 유망한 종목
@@ -184,15 +181,14 @@ def growth(code: str) -> dict:
     영업이익률은 기업의 경쟁력척도로 경쟁사에 비해 높으면 경제적해자를 갖춘셈
     """
     if utils.is_6digit(code):
-        c104 = mongo.C104(code)
-        c106 = mongo.C106(code)
+        c104 = mongo2.C104(client, code, 'c104y')
+        c106y = mongo2.C106Y(client, code)
     else:
         raise ValueError(f'Invalid code: {code}')
 
-    c104.chg_page('c104y')
     dict매출액증가율 = c104.find('매출액증가율')
 
-    c104.chg_page('c104q')
+    c104.page = 'c104q'
     d1, 매출액증가율 = c104.latest_value('매출액증가율')
 
     logger.info(f'매출액증가율 : {매출액증가율} {dict매출액증가율}')
@@ -200,9 +196,8 @@ def growth(code: str) -> dict:
     ################################################################
 
     # c106 에서 타 기업과 영업이익률 비교
-    c106.chg_page('c106y')
     try:
-        dict영업이익률 = c106.find('영업이익률')
+        dict영업이익률 = c106y.find('영업이익률')
     except KeyError:
         dict영업이익률 = {'Unnamed': float('nan')}
     logger.info(f'{code} 영업이익률 {dict영업이익률}')
@@ -251,11 +246,12 @@ def growth(code: str) -> dict:
 def _make_df_part(codes: list, q):
     def make_record(c: str) -> dict:
         # 장고에서 사용할 eval 테이블을 만들기 위해 각각의 레코드를 구성하는 함수
-        c101 = mongo.C101(code=c).get_recent()
+        client = mongo2.connect_mongo(MONGO_ADDR)
+        c101 = mongo2.C101(client, c).get_recent()
 
-        red_dict = red(code=c)
-        mil_dict = mil(code=c)
-        growth_dict = growth(code=c)
+        red_dict = red(client, c)
+        mil_dict = mil(client, c)
+        growth_dict = growth(client, c)
 
         mil_date = mil_dict['date']
         red_date = red_dict['date']
@@ -321,10 +317,10 @@ def make_today_eval_df(refresh: bool = False) -> pd.DataFrame:
         return n, divided_list
 
     today_str = datetime.datetime.today().strftime('%Y%m%d')
-    df = mongo.EvalByDate(date=today_str).get_data()
+    client = mongo2.connect_mongo(MONGO_ADDR)
+    df = mongo2.EvalWithDate(client, today_str).load_df()
     if refresh or len(df) == 0:
-        print(setting.load())
-        codes = mongo.Corps.get_all_corps()
+        codes = mongo2.Corps(client).get_all_corps()
 
         print('*' * 25, f"Eval all using multiprocess", '*' * 25)
         print(f'Total {len(codes)} items..')
@@ -348,10 +344,10 @@ def make_today_eval_df(refresh: bool = False) -> pd.DataFrame:
         print(f'Total spent time : {round(time.time() - start_time, 2)} sec.')
         logger.debug(final_df)
         print(f"Save to mongo db(db: eval col: {today_str}")
-        mongo.EvalByDate(date=today_str).save(final_df)
+        mongo2.EvalWithDate(client, today_str).save_df(final_df)
     else:
         print(f"Use saved dataframe from mongo db..")
-        final_df = mongo.EvalByDate(date=today_str).get_data()
+        final_df = mongo2.EvalWithDate(client, today_str).load_df()
     return final_df
 
 
@@ -362,7 +358,8 @@ def yield_valid_spac() -> tuple:
     Returns:
         tuple: (code, name, price)
     """
-    codes = mongo.Corps.get_all_corps()
+    client = mongo2.connect_mongo(MONGO_ADDR)
+    codes = mongo2.Corps(client).get_all_corps()
     logger.info(f'len(codes) : {len(codes)}')
     print('<<< Finding valuable SPAC >>>')
     for i, code in enumerate(codes):
