@@ -1,9 +1,9 @@
 """다양한 문자열 출력 형식에 맞춘 함수들
 """
-from db_hj3415 import mongo
+from db_hj3415 import mongo2
 from .eval import red as eval_red, mil as eval_mil, blue as eval_blue, growth as eval_growth
 from .score import red as score_red, mil as score_mil, blue as score_blue, growth as score_growth
-from .db import CorpsEval
+from .db import CorpsEval, MONGO_ADDR
 from util_hj3415 import utils
 from krx_hj3415 import krx
 import textwrap
@@ -18,7 +18,7 @@ logger.setLevel(logging.WARNING)
 
 
 class MakeStr:
-    
+    client = mongo2.connect_mongo(MONGO_ADDR)
     separate_line = '\n' + ('-' * 65) + '\n'
 
     def __init__(self, code: str):
@@ -26,7 +26,7 @@ class MakeStr:
         self.name = krx.get_name(code)
 
     def c101(self, full=True):
-        c101 = mongo.C101(self.code).get_recent()
+        c101 = mongo2.C101(self.client, self.code).get_recent()
         logger.info(c101)
 
         title = '=' * 35 + f"\t{c101['코드']}\t\t{c101['종목명']}\t\t{c101['업종']}\t" + '=' * 35
@@ -59,7 +59,7 @@ class MakeStr:
         return title + '\n' + intro + self.separate_line + price + '\n' + info
 
     def red(self, full=True) -> str:
-        red_dict = eval_red(self.code)
+        red_dict = eval_red(self.client, self.code)
         p, 괴리율 = score_red(self.code)
         logger.info(red_dict)
 
@@ -75,7 +75,7 @@ class MakeStr:
         return title + contents
 
     def mil(self, full=True) -> str:
-        mil_dict = eval_mil(self.code)
+        mil_dict = eval_mil(self.client, self.code)
         p1, p2, p3, p4 = score_mil(self.code)
         logger.info(mil_dict)
 
@@ -98,7 +98,7 @@ class MakeStr:
         return title + contents
 
     def blue(self, full=True) -> str:
-        blue_dict = eval_blue(self.code)
+        blue_dict = eval_blue(self.client, self.code)
         p1, p2, p3, p4, p5 = score_blue(self.code)
         logger.info(blue_dict)
 
@@ -115,7 +115,7 @@ class MakeStr:
         return title + contents
 
     def growth(self, full=True) -> str:
-        growth_dict = eval_growth(self.code)
+        growth_dict = eval_growth(self.client, self.code)
         p1, p2 = score_growth(self.code)
         logger.info(growth_dict)
 
@@ -130,9 +130,9 @@ class MakeStr:
 
     def c108(self, full=True) -> str:
         if full:
-            c108_list = mongo.C108(self.code).get_all()
+            c108_list = mongo2.C108(self.client, self.code).get_all()
         else:
-            c108_list = mongo.C108(self.code).get_recent()
+            c108_list = mongo2.C108(self.client, self.code).get_recent()
         s = ''
         logger.info(c108_list)
         for i, c108_dict in enumerate(c108_list):
@@ -177,13 +177,14 @@ def for_django(code: str) -> dict:
 
     장고의 view context는 딕셔너리 형식이기 때문에 딕셔너리 모음으로 반환한다.
     """
+    client = mongo2.connect_mongo(MONGO_ADDR)
     return {
-        'c101': mongo.C101(code).get_recent(),
-        'red': eval_red(code),
-        'mil': eval_mil(code),
-        'blue': eval_blue(code),
-        'growth': eval_growth(code),
-        'c108': mongo.C108(code).get_recent(),
+        'c101': mongo2.C101(client, code).get_recent(),
+        'red': eval_red(client, code),
+        'mil': eval_mil(client, code),
+        'blue': eval_blue(client, code),
+        'growth': eval_growth(client, code),
+        'c108': mongo2.C108(client, code).get_recent(),
         'red_s': score_red(code),
         'mil_s': score_mil(code),
         'blue_s': score_blue(code),
