@@ -1,10 +1,10 @@
 import math
 import numpy
 import pprint
-from .db import CorpsEval
+from .db import CorpsEval, MONGO_ADDR
 from .eval import EXPECT_EARN, red as eval_red, mil as eval_mil, blue as eval_blue, growth as eval_growth
 
-from db_hj3415 import mongo
+from db_hj3415 import mongo2
 from util_hj3415 import utils
 from krx_hj3415 import krx
 import copy
@@ -19,11 +19,6 @@ logger.addHandler(ch)
 logger.setLevel(logging.WARNING)
 
 
-corps_eval = CorpsEval(code='005930')
-c101 = mongo.C101(code='005930')
-c104 = mongo.C104(code='005930')
-
-
 def red(code: str) -> tuple:
     """red price와 최근 주가의 괴리율 파악
 
@@ -38,8 +33,8 @@ def red(code: str) -> tuple:
         {'red_price': 47896, '사업가치': 7127.5, '재산가치': 7152.78, '부채평가': 902.4, '발행주식수': 27931.0}\n
     """
     if utils.is_6digit(code):
-        corps_eval.chg_code(code)
-        c101.chg_code(code)
+        client = mongo2.connect_mongo(MONGO_ADDR)
+        c101 = mongo2.C101(client, code)
     else:
         raise ValueError(f'Invalid code: {code}')
 
@@ -49,7 +44,7 @@ def red(code: str) -> tuple:
         recent_price = utils.to_int(c101.get_recent()['주가'])
     except KeyError:
         recent_price = float('nan')
-    red_price = eval_red(code=code)['red_price']
+    red_price = eval_red(client, code)['red_price']
 
     logger.info(f"recent_price : {recent_price}\tred_price : {red_price}")
 
@@ -116,11 +111,12 @@ def mil(code: str) -> tuple:
     """
 
     if utils.is_6digit(code):
-        corps_eval.chg_code(code)
+        corps_eval = CorpsEval(code)
     else:
         raise ValueError(f'Invalid code: {code}')
 
-    mil_dict = eval_mil(code)
+    client = mongo2.connect_mongo(MONGO_ADDR)
+    mil_dict = eval_mil(client, code)
 
     logger.info(pprint.pformat(mil_dict, width=200))
 
@@ -217,12 +213,13 @@ def blue(code: str) -> tuple:
         return int(p)
 
     if utils.is_6digit(code):
-        corps_eval.chg_code(code)
-        c104.chg_code(code)
+        client = mongo2.connect_mongo(MONGO_ADDR)
+        corps_eval = CorpsEval(code)
+        c104 = mongo2.C104(client, code, 'c104y')
     else:
         raise ValueError(f'Invalid code: {code}')
 
-    blue_dict = eval_blue(code)
+    blue_dict = eval_blue(client, code)
 
     logger.info(pprint.pformat(blue_dict, width=200))
 
@@ -247,8 +244,8 @@ def blue(code: str) -> tuple:
         if math.isnan(최근분기) or 최근분기 <= 1:
             # 최근 분기의 값이 비정상이면 최근 년도를 한번 더 비교해 보지만 좀더 엄격하게 전년대비도 비교한다.
             _, 최근연도 = corps_eval.get_recent(dict_y)
-            c104.chg_page(page='c104y')
-            전년대비 = c104.find_cmp(title='이자보상배율')
+            c104.page = 'c104y'
+            _, 전년대비 = c104.find_cmp(title='이자보상배율').popitem()
             if math.isnan(최근연도) or 최근연도 <= 1 or math.isnan(전년대비) or 전년대비 < 0:
                 p = NEG_MAX
             else:
@@ -269,8 +266,8 @@ def blue(code: str) -> tuple:
         if math.isnan(최근분기) or 최근분기 >= 80:
             # 최근 분기의 값이 비정상이면 최근 년도를 한번 더 비교해 보지만 좀더 엄격하게 전년대비도 비교한다.
             _, 최근연도 = corps_eval.get_recent(dict_y)
-            c104.chg_page(page='c104y')
-            전년대비 = c104.find_cmp(title='순부채비율')
+            c104.page = 'c104y'
+            _, 전년대비 = c104.find_cmp(title='순부채비율').popitem()
             if math.isnan(최근연도) or 최근연도 >= 80 or math.isnan(전년대비) or 전년대비 > 0:
                 p = NEG_MAX
             else:
@@ -322,12 +319,12 @@ def growth(code: str) -> tuple:
     """
 
     if utils.is_6digit(code):
-        corps_eval.chg_code(code)
-        c104.chg_code(code)
+        corps_eval = CorpsEval(code)
     else:
         raise ValueError(f'Invalid code: {code}')
 
-    growth_dict = eval_growth(code)
+    client = mongo2.connect_mongo(MONGO_ADDR)
+    growth_dict = eval_growth(client, code)
 
     logger.debug(pprint.pformat(growth_dict, width=200))
 
